# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir          qtquick3dphysics-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtquick3dphysics   %mklibname qt%{qtmajor}quick3dphysics %{qtmajor}
%define libqtquick3dphysics_d %mklibname qt%{qtmajor}quick3dphysics -d

Name:           qtquick3dphysics6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Quick3d Physics component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

BuildRequires:  qtbase6-devel >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6Quick3D) >= %{version}
BuildRequires:  ninja
BuildRequires:  qttools6

Provides:       qt%{qtmajor}-qtquick3dphysics = %{version}-%{release}

%description
Qt%{qtmajor} Quick3d Physics API provides quick3dphysics information
via QML and C++ interfaces.

%files
%{_qt6_bindir}/cooker
%{_qt6_archdatadir}/qml/QtQuick3D/Physics/
%{_qt6_archdatadir}/sbom/qtquick3dphysics-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        Qt%{qtmajor} Quick3d Physics APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in Qt%{qtmajor} Quick3d Physics package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtquick3dphysics.qch
%{_qt6_docdir}/qtquick3dphysics/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtquick3dphysics}
Summary:        Qt%{qtmajor} Quick3d Physics Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description -n %{libqtquick3dphysics}
Qt%{qtmajor} Quick3d Physics Component Library.

The Quick3d Physics module provides quick3dphysics information via QML
and C++ interfaces.

%files -n %{libqtquick3dphysics}
%{_qt6_libdir}/libQt6Quick3DPhysics.so.%{qtmajor}{,.*}
%{_qt6_libdir}/libQt6Quick3DPhysicsHelpers.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtquick3dphysics_d}
Summary:        Devel files needed to build apps based on QtQuick3dPhysics
Group:          Development/KDE and Qt
Requires:       qtquick3dphysics6 = %version
Requires:       %{libqtquick3dphysics} = %version
Provides:       libqtquick3dphysics6-devel = %version
Provides:       libqt6quick3dphysics-devel = %version
Provides:       qtquick3dphysics6-devel = %version
Provides:       qt6quick3dphysics-devel = %version

Provides:       libqtquick3dphysics6-private-devel = %version
Provides:       libqt6quick3dphysics-private-devel = %version
Provides:       qtquick3dphysics6-private-devel = %version
Provides:       qt6quick3dphysics-private-devel = %version

%description -n %{libqtquick3dphysics_d}
Devel files needed to build apps based on Qt Quick3D Physics.

%files -n %{libqtquick3dphysics_d}
%{_qt6_headerdir}/QtQuick3DPhysics/
%{_qt6_headerdir}/QtQuick3DPhysicsHelpers/
%{_qt6_libdir}/libQt6Quick3DPhysics.so
%{_qt6_libdir}/libQt6Quick3DPhysics.prl
%{_qt6_libdir}/libQt6Quick3DPhysicsHelpers.so
%{_qt6_libdir}/libQt6Quick3DPhysicsHelpers.prl
%{_qt6_libdir}/cmake/Qt6/FindWrapBundledPhysXConfigExtra.cmake
%{_qt6_libdir}/cmake/Qt6Quick3DPhysics/
%{_qt6_libdir}/cmake/Qt6Quick3DPhysicsHelpers/
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake
%{_qt6_libdir}/cmake/Qt6BundledPhysX/*.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtQuick3DPhysicsTestsConfig.cmake
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_quick3dphysics*.pri
%{_qt6_libdir}/qt6/metatypes/qt6*_metatypes.json
%{_qt6_libdir}/qt6/modules/Quick3DPhysics*.json
%{_qt6_libdir}/pkgconfig/*.pc
%if %{with examples}
%{_qt6_examplesdir}/quick3dphysics
%endif

#------------------------------------------------------------------------------

%prep
%setup -q -n qtquick3dphysics-everywhere-src-%{qtversion}

%build
%ifarch %{ix86}
export CXXFLAGS="$CXXFLAGS -msse2 -g"
%endif

%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif

# remove static library
rm -f %{buildroot}%{_libdir}/libQt6BundledPhysX.a


%changelog
* Wed Mar 26 2025 daviddavid <daviddavid> 6.8.3-1.mga10
+ Revision: 2170115
- New version 6.8.3

* Wed Dec 18 2024 daviddavid <daviddavid> 6.8.1-1.mga10
+ Revision: 2125919
- New version 6.8.1

* Sat Oct 05 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103615
- New version 6.7.3
- enable docs building

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083113
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072546
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Thu May 23 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2066225
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041647
- New version 6.6.2

* Thu Oct 19 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999042
- New version 6.6.0

* Mon Sep 11 2023 neoclust <neoclust> 6.5.2-1.mga10
+ Revision: 1986120
- New version 6.5.2

* Tue Dec 27 2022 daviddavid <daviddavid> 6.4.1-2.mga9
+ Revision: 1927063
- build examples

* Fri Dec 16 2022 neoclust <neoclust> 6.4.1-1.mga9
+ Revision: 1923618
- New version 6.4.1

* Wed Oct 19 2022 papoteur <papoteur> 6.4.0-1.mga9
+ Revision: 1897542
- build on i586 with sse2
- imported package qtquick3dphysics6

